@@ -13,7 +13,7 @@ _fields_list = ['created_at', 'id_str', 'conversation_id_str', 'full_text', 'lan
                 'retweet_count', 'favorite_count', 'reply_count', 'quote_count', 'quoted_status_id_str',
                 'quoted_status_short_url', 'quoted_status_expand_url', 'user_id_str', 'user_name', 'user_full_name',
                 'user_verified', 'in_reply_to_status_id_str', 'in_reply_to_user_id_str', 'hashtags', 'mentions',
-                'urls']
+                'urls', 'media']
 
 
 class CsvTweetOutput(TweetOutput):
